@@ -5,14 +5,13 @@ import operator
 import sys
 import warnings
 import weakref
+from collections.abc import Callable
 from contextlib import suppress
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     ClassVar,
     Literal,
-    Optional,
     TypeVar,
     cast,
     overload,
@@ -25,14 +24,13 @@ from ._signal import Signal, SignalInstance
 if TYPE_CHECKING:
     from _weakref import ref as ref
     from collections.abc import Iterable, Mapping
-
-    from typing_extensions import TypeAlias
+    from typing import TypeAlias
 
     from psygnal._group import EmissionInfo
     from psygnal._weak_callback import RefErrorChoice, WeakCallback
 
     EqOperator: TypeAlias = Callable[[Any, Any], bool]
-    FieldAliasFunc: TypeAlias = Callable[[str], Optional[str]]
+    FieldAliasFunc: TypeAlias = Callable[[str], str | None]
 
 __all__ = ["SignalGroupDescriptor", "get_evented_namespace", "is_evented"]
 
@@ -702,8 +700,12 @@ class SignalGroupDescriptor:
 
             # Register callback to connect child events on first connection if requested
             if self._connect_child_events:
+                try:
+                    ref_ = weakref.ref(instance)
+                except TypeError:
+                    ref_ = instance  # type: ignore
                 grp._psygnal_relay._on_first_connect_callbacks.append(
-                    lambda: connect_child_events(instance, recurse=True, _group=grp)
+                    lambda: connect_child_events(ref_, recurse=True, _group=grp)
                 )
 
         return self._instance_map[obj_id]
@@ -771,6 +773,10 @@ def connect_child_events(
         The SignalGroup to connect to.  If not provided, will be found by calling
         `get_evented_namespace(obj)`. By default None.
     """
+    if isinstance(obj, weakref.ref):
+        obj = obj()
+        if obj is None:
+            return  # pragma: no cover
     if _group is None and (_group := _find_signal_group(obj)) is None:
         return  # pragma: no cover  # not evented
 
